Što je OiRA? | OiRA

Teme

# Što je OiRA?

## Novi ste korisnik sustava OiRA?

Slijedi kratak uvod u procjenu rizika i način na koji vam sustav OiRA može pomoći u upravljanju procjenom.

## Što je procjena rizika?

Procjena rizika temelj je za uspješno upravljanje sigurnošću i zdravljem te ključan čimbenik za smanjenje broja nesreća povezanih s radom i profesionalnih bolesti. Ako se provodi na odgovarajući način, procjenom rizika mogu se poboljšati sigurnost i zdravlje na radnom mjestu te poslovni rezultati općenito.

U Europi se sigurnost i zdravlje radnika štite tako što se provodi procjena rizika na radnom mjestu i upravlja tim rizicima. Poslodavci imaju pravnu obvezu zajamčiti sigurnost i zdravlje radnika u svakom aspektu povezanom s radom te provoditi procjenu rizika. Svako poduzeće stoga mora provesti procjenu rizika i sastaviti plan mjera. Kako bi se provela djelotvorna procjena rizika na radnom mjestu, svi dionici uključeni u procjenu moraju dobro poznavati:

- pravni kontekst i koncepte;
- postupak koji se primjenjuje za procjenu rizika;
- ulogu koju će imati glavni dionici koji sudjeluju u tom postupku.

Radnici i/ili njihovi predstavnici imaju pravo na to da se glavni dionici s njima savjetuju o mehanizmima za provedbu procjene rizika i na to da u njoj sudjeluju.

Dodatne informacije o procjeni rizika i sudjelovanju radnika i/ili njihovih predstavnika u postupku procjene rizika namazi se na mrežnom mjestu projekta OiRA.

## Što je OiRA?

OiRA je pokrata za internetski alat za interaktivnu procjenu rizika. Riječ je o internetskoj aplikaciji koja vam omogućuje da provedete procjenu rizika za sigurnost i zdravlje na svojem radnom mjestu.

## Kome je alat OiRA namijenjen?

Alat OiRA može upotrebljavati svatko tko želi procijeniti moguće rizike povezane sa sigurnošću i zdravljem na svojem radnom mjestu.

Međutim, alat OiRA osmišljen je tako da bude od najveće koristi malim poduzećima. Posebno je izrađen kako bi takvim poduzećima pomogao da procijene rizike na radu i provedu dokumentiranu procjenu rizika te sastave plan mjera prilagođen zahtjevima konkretne organizacije.

## Što trebam učiniti?

U okviru postupka procjene rizika u sustavu OiRA potrebno je izvršiti nekoliko koraka:

- Priprema: uz određene alate dostupna su pitanja za profiliranje koja vam omogućuju da alat prilagodite specifičnim potrebama svoje organizacije. Nakon što odgovorite na pitanja za profiliranje, alat će se prilagoditi vašoj konkretnoj situaciji i prikazat će se primjenjivi moduli.

- Sudjelovanje: svaka procjena rizika trebala bi se provesti uz aktivno sudjelovanje radnika. Alat vam omogućuje da ispišete potpun tekst procjene rizika ili njegove dijelove kako biste obavijestili radnike i od njih dobili povratne informacije.

- Utvrđivanje rizika: U sustavu OiRA prikazat će se niz mogućih opasnosti ili problema povezanih sa sigurnošću i zdravljem na vašem radnom mjestu. Utvrdite postoje li takve opasnosti ili problemi na vašem radnom mjestu tako što ćete na tvrdnje/pitanja odgovoriti s „da” ili „ne”. Odgovore na neka pitanja možete ostaviti i prazne, odnosno staviti ih „na čekanje” i na njih odgovoriti kasnije.

- Procjena: u nekim ćete alatima trebati odrediti prioritete u pogledu rizika koje ste utvrdili. To možete učiniti na različite načine, ovisno o odlukama koje su donijeli naši nacionalni partneri za alat OiRA ili programeri alata OiRA i konkretnom pristupu koji oni primjenjuju. Isto tako, u nekim se alatima prioriteti u pogledu rizika određuju automatski u pozadini, a vi ih možete poništiti.

- Plan mjera: za svaki utvrđeni rizik u alatu će se od vas zatražiti da odaberete jednu ili više mjera s pomoću koje ćete taj rizik ukloniti ili smanjiti. U većini alata predložit će vam se određene mjere. Uvijek možete unijeti i svoje mjere.

- Završni dokumenti: vaša je pravna obveza dokumentirati procjenu rizika. U odjeljku s izvješćima možete pronaći različita izvješća koja će vam pomoći u tome da vodite evidenciju o svojoj procjeni rizika i provedete aktivnosti/mjere koje ste odabrali kako biste uklonili ili ublažili utvrđene rizike.

## Koliko će procjena rizika trajati?

Općenito se ne može odrediti koliko će procjena rizika trajati jer se alati razlikuju ovisno o sektoru i zemlji.

Međutim, procjeni možete posvetiti vrijeme koje vam je u određenom trenutku na raspolaganju, a zatim se vratiti kad vam to odgovara i nastaviti gdje ste stali.

## Zašto se trebam registrirati?

Kad započnete svoju prvu procjenu rizika, od vas će se najprije tražiti da kreirate račun u sustavu OiRA. Postupak je jednostavan i brz.

Nakon što se registrirate, u svakom ćete se trenutku moći jednostavno prijaviti i nastaviti s prethodnim procjenama ili pokrenuti nove procjene.

Kao registrirani korisnik uvijek možete dobiti ispisanu, točnu i ažuriranu procjenu rizika.

## Moram li se pripremati?

Da biste počeli upotrebljavati alat, nije vam potrebna nikakva posebna priprema. Međutim, svakako odvojite dovoljno vremena kako biste razmislili o tome tko će provesti procjenu rizika i kako će radnici sudjelovati u tom postupku.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More